Module factorization

Module factorization 

Prime factorization helpers.

Functions

factorization
Returns the prime factorization of n as (prime, exponent) pairs.
prime_factors
Returns the prime factors of n, including repeated multiplicities.
unique_prime_factors
Returns the unique prime factors of n in ascending order.