pub const fn checked_lcm(left: u64, right: u64) -> Option<u64>Expand description
Computes the least common multiple of two unsigned integers.
Returns None when the exact result does not fit in u64.
Examples
use use_arithmetic::checked_lcm;
assert_eq!(checked_lcm(6, 15), Some(30));
assert_eq!(checked_lcm(0, 15), Some(0));