geode_on_first_axis

Function geode_on_first_axis 

pub fn geode_on_first_axis(n: u64) -> Result<u128, GeodeError>
Returns the Geode coefficient along the first axis [n].

Errors

Returns any validation or arithmetic error produced while constructing the axis vector or evaluating geode.