pub fn sample_std_dev(values: &[f64]) -> Result<f64, StatisticsError>Expand description
Returns the sample standard deviation of values using Bessel’s correction.
Errors
Propagates any error returned by sample_variance.
pub fn sample_std_dev(values: &[f64]) -> Result<f64, StatisticsError>Returns the sample standard deviation of values using Bessel’s correction.
Propagates any error returned by sample_variance.