pub fn sieve(limit: usize) -> Vec<bool>
Returns a boolean sieve up to and including limit.
limit
The returned vector has length limit + 1, and index i is true exactly when i is prime.
limit + 1
i
true