pub fn solve_linear(a: f64, b: f64) -> RootsExpand description
Solves the linear equation ax + b = 0.
Returns Roots::Infinite when both coefficients are zero, and
Roots::None when the equation has no finite real root.
pub fn solve_linear(a: f64, b: f64) -> RootsSolves the linear equation ax + b = 0.
Returns Roots::Infinite when both coefficients are zero, and
Roots::None when the equation has no finite real root.