pub struct CollatzRangeSummary {
pub start: u64,
pub end: u64,
pub checked: u64,
pub reached_one: u64,
pub overflowed: u64,
pub max_total_stopping_time: Option<(u64, u64)>,
pub max_trajectory_value: Option<(u64, u64)>,
}Expand description
Summary information for an inclusive range checked with verify_range.
max_total_stopping_time stores (input, total_stopping_time).
max_trajectory_value stores (input, max_value_in_trajectory).
Fields
start: u64The inclusive lower bound that was requested.
end: u64The inclusive upper bound that was requested.
checked: u64The number of positive inputs checked in the inclusive range.
reached_one: u64The number of checked inputs whose trajectories reached 1 without overflow.
overflowed: u64The number of checked inputs whose odd-step arithmetic overflowed.
max_total_stopping_time: Option<(u64, u64)>The input with the largest total stopping time, if any values were checked.
max_trajectory_value: Option<(u64, u64)>The input with the largest peak trajectory value, if any values were checked.