pub struct EigenSpace<T> { /* private fields */ }Expand description
The eigenspace associated with one eigenvalue.
Implementations
Sourceimpl<T> EigenSpace<T>
impl<T> EigenSpace<T>
Sourcepub fn new(
value: Eigenvalue<T>,
basis: Vec<Eigenvector<T>>,
) -> Result<EigenSpace<T>, EigenError>
pub fn new( value: Eigenvalue<T>, basis: Vec<Eigenvector<T>>, ) -> Result<EigenSpace<T>, EigenError>
Creates a new eigenspace from an eigenvalue and basis vectors.
Errors
Returns EigenError::EmptyEigenspace when basis is empty.
Sourcepub fn try_new(
value: Eigenvalue<T>,
basis: Vec<Eigenvector<T>>,
) -> Result<EigenSpace<T>, EigenError>
pub fn try_new( value: Eigenvalue<T>, basis: Vec<Eigenvector<T>>, ) -> Result<EigenSpace<T>, EigenError>
Creates a new eigenspace from an eigenvalue and basis vectors.
Errors
Returns EigenError::EmptyEigenspace when basis is empty.
Sourcepub const fn value(&self) -> &Eigenvalue<T>
pub const fn value(&self) -> &Eigenvalue<T>
Returns the associated eigenvalue.
Sourcepub fn basis(&self) -> &[Eigenvector<T>]
pub fn basis(&self) -> &[Eigenvector<T>]
Returns the basis vectors.
Sourcepub fn into_inner(self) -> (Eigenvalue<T>, Vec<Eigenvector<T>>)
pub fn into_inner(self) -> (Eigenvalue<T>, Vec<Eigenvector<T>>)
Returns the stored eigenvalue and basis vectors.