Vector

Struct Vector 

pub struct Vector<const N: usize> { /* private fields */ }
A vector with N plain f64 components.

Examples

use use_vector::Vector;

let vector = Vector::<3>::from_array([2.0, 3.0, 6.0]);

assert_eq!(vector.dimension(), 3);
assert_eq!(vector.magnitude(), 7.0);

Implementations

Source

impl<const N: usize> Vector<N>

pub const ZERO: Vector<N>

The zero vector.

pub const ONE: Vector<N>

A vector with every component set to 1.0.

pub const fn from_array(components: [f64; N]) -> Vector<N>

Creates a vector from its component array.

pub const fn as_array(&self) -> &[f64; N]

Returns a shared reference to the component array.

pub const fn into_array(self) -> [f64; N]

Returns the component array.

pub const fn dimension(self) -> usize

Returns the vector dimension.

pub fn dot(self, other: Vector<N>) -> f64

Returns the dot product with other.

Examples
use use_vector::Vector;

let a = Vector::<3>::from_array([1.0, 2.0, 3.0]);
let b = Vector::<3>::from_array([4.0, 5.0, 6.0]);

assert_eq!(a.dot(b), 32.0);
pub fn magnitude_squared(self) -> f64

Returns the squared Euclidean magnitude.

pub fn magnitude(self) -> f64

Returns the Euclidean magnitude.

pub fn normalize(self) -> Option<Vector<N>>

Returns a normalized vector when the magnitude is finite and non-zero.

Returns None for zero vectors or vectors with non-finite magnitude.

Examples
use use_vector::Vector2;

let unit = Vector2::new(3.0, 4.0)
    .normalize()
    .expect("non-zero finite vector should normalize");

assert!((unit.x() - 0.6).abs() < 1.0e-12);
assert!((unit.y() - 0.8).abs() < 1.0e-12);
pub fn scale(self, scalar: f64) -> Vector<N>

Returns the vector scaled by scalar.

pub fn distance(self, other: Vector<N>) -> f64

Returns the Euclidean distance to other.

Examples
use use_vector::Vector2;

let start = Vector2::ZERO;
let end = Vector2::new(3.0, 4.0);

assert_eq!(start.distance(end), 5.0);
pub fn distance_squared(self, other: Vector<N>) -> f64

Returns the squared Euclidean distance to other.

pub fn lerp(self, other: Vector<N>, t: f64) -> Vector<N>

Returns the linear interpolation between self and other for t.

pub fn map_components(self, mapper: impl FnMut(f64) -> f64) -> Vector<N>

Maps each component with mapper.

pub fn zip_components( self, other: Vector<N>, mapper: impl FnMut(f64, f64) -> f64, ) -> Vector<N>

Combines components from self and other with mapper.

pub fn component_min(self, other: Vector<N>) -> Vector<N>

Returns the component-wise minimum with other.

pub fn component_max(self, other: Vector<N>) -> Vector<N>

Returns the component-wise maximum with other.

pub fn clamp_components( self, minimum: Vector<N>, maximum: Vector<N>, ) -> Vector<N>

Returns each component bounded by the matching minimum and maximum components.

pub fn abs(self) -> Vector<N>

Returns a vector with the absolute value of each component.

pub fn is_finite(self) -> bool

Returns true when every component is finite.

pub fn is_nan(self) -> bool

Returns true when any component is NaN.

Source

impl Vector<2>

pub const fn new(x: f64, y: f64) -> Vector<2>

Creates a two-dimensional vector from its components.

pub const fn x(self) -> f64

Returns the x component.

pub const fn y(self) -> f64

Returns the y component.

Source

impl Vector<3>

pub const fn new(x: f64, y: f64, z: f64) -> Vector<3>

Creates a three-dimensional vector from its components.

pub const fn x(self) -> f64

Returns the x component.

pub const fn y(self) -> f64

Returns the y component.

pub const fn z(self) -> f64

Returns the z component.

pub fn cross(self, other: Vector<3>) -> Vector<3>

Returns the cross product with other.

Examples
use use_vector::Vector3;

let x = Vector3::new(1.0, 0.0, 0.0);
let y = Vector3::new(0.0, 1.0, 0.0);

assert_eq!(x.cross(y), Vector3::new(0.0, 0.0, 1.0));
Source

impl Vector<4>

pub const fn new(x: f64, y: f64, z: f64, w: f64) -> Vector<4>

Creates a four-dimensional vector from its components.

pub const fn x(self) -> f64

Returns the x component.

pub const fn y(self) -> f64

Returns the y component.

pub const fn z(self) -> f64

Returns the z component.

pub const fn w(self) -> f64

Returns the w component.